==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/customerinsights/kotlin/inputs/GetPredictionModelStatusPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.customerinsights.kotlin.inputs

import com.pulumi.azurenative.customerinsights.inputs.GetPredictionModelStatusPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property hubName The name of the hub.
 * @property predictionName The name of the Prediction.
 * @property resourceGroupName The name of the resource group.
 */
public data class GetPredictionModelStatusPlainArgs(
    public val hubName: String,
    public val predictionName: String,
    public val resourceGroupName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.customerinsights.inputs.GetPredictionModelStatusPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.customerinsights.inputs.GetPredictionModelStatusPlainArgs =
        com.pulumi.azurenative.customerinsights.inputs.GetPredictionModelStatusPlainArgs.builder()
            .hubName(hubName.let({ args0 -> args0 }))
            .predictionName(predictionName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetPredictionModelStatusPlainArgs].
 */
@PulumiTagMarker
public class GetPredictionModelStatusPlainArgsBuilder internal constructor() {
    private var hubName: String? = null

    private var predictionName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The name of the hub.
     */
    @JvmName("sxtnaqpltkbdhbma")
    public suspend fun hubName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.hubName = mapped
    }

    /**
     * @param value The name of the Prediction.
     */
    @JvmName("tjqswrgracxwceaf")
    public suspend fun predictionName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.predictionName = mapped
    }

    /**
     * @param value The name of the resource group.
     */
    @JvmName("nsvuelohxvbsygyu")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetPredictionModelStatusPlainArgs = GetPredictionModelStatusPlainArgs(
        hubName = hubName ?: throw PulumiNullFieldException("hubName"),
        predictionName = predictionName ?: throw PulumiNullFieldException("predictionName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/customerinsights/kotlin/inputs/GetPredictionModelStatusPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.customerinsights.kotlin.inputs

import com.pulumi.azurenative.customerinsights.inputs.GetPredictionModelStatusPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property hubName The name of the hub.
 * @property predictionName The name of the Prediction.
 * @property resourceGroupName The name of the resource group.
 */
public data class GetPredictionModelStatusPlainArgs(
    public val hubName: String,
    public val predictionName: String,
    public val resourceGroupName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.customerinsights.inputs.GetPredictionModelStatusPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.customerinsights.inputs.GetPredictionModelStatusPlainArgs =
        com.pulumi.azurenative.customerinsights.inputs.GetPredictionModelStatusPlainArgs.builder()
            .hubName(hubName.let({ args0 -> args0 }))
            .predictionName(predictionName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetPredictionModelStatusPlainArgs].
 */
@PulumiTagMarker
public class GetPredictionModelStatusPlainArgsBuilder internal constructor() {
    private var hubName: String? = null

    private var predictionName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The name of the hub.
     */
    @JvmName("yoaeajntjtvcjhgl")
    public suspend fun hubName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.hubName = mapped
    }

    /**
     * @param value The name of the Prediction.
     */
    @JvmName("csdpfrphvqhdjdcm")
    public suspend fun predictionName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.predictionName = mapped
    }

    /**
     * @param value The name of the resource group.
     */
    @JvmName("yqnwkgvnovwdlkte")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetPredictionModelStatusPlainArgs = GetPredictionModelStatusPlainArgs(
        hubName = hubName ?: throw PulumiNullFieldException("hubName"),
        predictionName = predictionName ?: throw PulumiNullFieldException("predictionName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}
